pub struct InstanceRef<'a, T>(/* private fields */)
where
T: Component;Expand description
A QueryData item which represents a reference to an Instance<T> and its associated Component.
This is analogous to a (Instance<T>, &T) query.
Usage
If a Kind is also a component, it is often convenient to access the instance and component data together.
This type is designed to make these queries more ergonomic.
You may use this type as either a Query parameter, or access it from an EntityRef.
Example
#[derive(Component)]
struct Apple {
freshness: f32,
}
impl Apple {
fn is_fresh(&self) -> bool {
self.freshness >= 0.5
}
}
// Query Access:
fn fresh_apples(query: Query<InstanceRef<Apple>>) -> Vec<Instance<Apple>> {
query.iter()
.filter_map(|apple| apple.is_fresh().then_some(apple.instance()))
.collect()
}
// Entity Access:
fn fresh_apples_world<'a>(world: &'a World) -> Vec<InstanceRef<'a, Apple>> {
world.try_query::<EntityRef>()
.unwrap()
.iter(&world)
.filter_map(|entity| InstanceRef::from_entity(entity))
.collect()
}
Implementations
Sourceimpl<'a, T> InstanceRef<'a, T>where
T: Component,
impl<'a, T> InstanceRef<'a, T>where
T: Component,
Sourcepub fn from_entity(entity: EntityRef<'a>) -> Option<InstanceRef<'a, T>>
pub fn from_entity(entity: EntityRef<'a>) -> Option<InstanceRef<'a, T>>
Creates a new InstanceRef<T> from an EntityRef if it contains a given Component of type T.
Sourcepub unsafe fn from_entity_unchecked(entity: EntityRef<'a>) -> InstanceRef<'a, T>
pub unsafe fn from_entity_unchecked(entity: EntityRef<'a>) -> InstanceRef<'a, T>
Creates a new InstanceRef<T> from EntityRef without any validation.
Safety
Assumes entity is a valid instance of kind T.