pub enum LoadError {
Io(Error),
Ron(Error),
Scene(SceneSpawnError),
}Expand description
An error which indicates a failure during the load process.
Variants
Io(Error)
Indicates a failure to access the saved data.
Ron(Error)
Indicates a deserialization error.
Scene(SceneSpawnError)
Indicates a failure to reconstruct the world from the loaded data.