pub struct LoadWorld<U = Or<(With<Save>, With<Unload>)>>where
U: QueryFilter,{
pub input: LoadInput,
pub mapper: SceneMapper,
/* private fields */
}Expand description
A generic LoadEvent which loads the world from a file or stream.
Fields
input: LoadInputThe input data used to load the world.
mapper: SceneMapperA SceneMapper used to map components after the load process.
Implementations
Sourceimpl<U> LoadWorld<U>where
U: QueryFilter,
impl<U> LoadWorld<U>where
U: QueryFilter,
Sourcepub fn new(input: LoadInput, mapper: SceneMapper) -> LoadWorld<U>
pub fn new(input: LoadInput, mapper: SceneMapper) -> LoadWorld<U>
Creates a new LoadWorld with the given input and mapper.
Sourcepub fn from_file(path: impl Into<PathBuf>) -> LoadWorld<U>
pub fn from_file(path: impl Into<PathBuf>) -> LoadWorld<U>
Creates a new LoadWorld which unloads entities matching the given
QueryFilter before the file at given path.
Sourcepub fn from_stream(stream: impl LoadStream) -> LoadWorld<U>
pub fn from_stream(stream: impl LoadStream) -> LoadWorld<U>
Creates a new LoadWorld which unloads entities matching the given
QueryFilter before loading from the given Read stream.
Sourcepub fn map_component<T>(self, m: impl MapComponent<T>) -> LoadWorld<U>where
T: Component,
pub fn map_component<T>(self, m: impl MapComponent<T>) -> LoadWorld<U>where
T: Component,
Maps the given Component into another using a component mapper after loading.
Sourceimpl LoadWorld
impl LoadWorld
Sourcepub fn default_from_file(path: impl Into<PathBuf>) -> LoadWorld
pub fn default_from_file(path: impl Into<PathBuf>) -> LoadWorld
Sourcepub fn default_from_stream(stream: impl LoadStream) -> LoadWorld
pub fn default_from_stream(stream: impl LoadStream) -> LoadWorld