Loaded

Struct Loaded 

pub struct Loaded {
    pub entity_map: EntityHashMap<Entity>,
}
An Event triggered at the end of a successful load process.

This event contains the loaded entity map.

Fields

entity_map: EntityHashMap<Entity>

The map of all loaded entities and their new entity IDs.

Implementations

Source

impl Loaded

pub fn entities(&self) -> impl Iterator<Item = Entity>

Iterates over all loaded entities.

Note that not all of these entities may be valid. This would indicate an error with save data. See unsaved.rs test for an example of how this may happen.