pub struct InstanceMut<'a, T>(/* private fields */)
where
T: Component;Expand description
A QueryData item which represents a mutable reference to an Instance<T> and its associated Component.
This is analogous to a (Instance<T>, &mut T) query.
Usage
This type behaves similar like InstanceRef<T> but allows mutable access to its associated Component.
The main difference is that you cannot create an InstanceMut<T> from an EntityMut.
See InstanceMut::from_entity for more details.
See InstanceRef<T> for more information and examples.
Implementations
Sourceimpl<'a, T> InstanceMut<'a, T>
impl<'a, T> InstanceMut<'a, T>
Sourcepub fn from_entity(entity: EntityMut<'a>) -> Option<InstanceMut<'a, T>>
pub fn from_entity(entity: EntityMut<'a>) -> Option<InstanceMut<'a, T>>
Creates a new InstanceMut<T> from an EntityWorldMut if it contains a given Component of type T.
Sourcepub unsafe fn from_entity_unchecked(entity: EntityMut<'a>) -> InstanceMut<'a, T>
pub unsafe fn from_entity_unchecked(entity: EntityMut<'a>) -> InstanceMut<'a, T>
Creates a new InstanceMut<T> from an EntityMut without any validation.
Safety
Assumes entity is a valid instance of kind T.