SaveWorld

Struct SaveWorld 

pub struct SaveWorld<F = With<Save>>
where F: QueryFilter,
{ pub entities: EntityFilter, pub resources: SceneFilter, pub components: SceneFilter, pub mapper: SceneMapper, pub output: SaveOutput, /* private fields */ }
A generic SaveEvent which can be used to save the World.

Fields

entities: EntityFilter

A filter for selecting which entities should be saved.

By default, all entities are selected.

resources: SceneFilter

A filter for selecting which resources should be saved.

By default, no resources are selected. Most Bevy resources are not safely serializable.

components: SceneFilter

A filter for selecting which components should be saved.

By default, all serializable components are selected.

mapper: SceneMapper

A mapper for transforming components during the save process.

See MapComponent for more information.

output: SaveOutput

Output of the saved world.

Implementations

Source

impl<F> SaveWorld<F>
where F: QueryFilter,

pub fn new(output: SaveOutput) -> SaveWorld<F>

Creates a new SaveWorld event with the given SaveOutput.

pub fn into_file(path: impl Into<PathBuf>) -> SaveWorld<F>

Creates a new SaveWorld event which saves entities matching the given QueryFilter into a file at the given path.

pub fn into_stream(stream: impl SaveStream) -> SaveWorld<F>

Creates a new SaveWorld event which saves entities matching the given QueryFilter into a Write stream.

pub fn include_resource<R>(self) -> SaveWorld<F>
where R: Resource,

Includes the given Resource in the save data.

pub fn include_resource_by_id(self, type_id: TypeId) -> SaveWorld<F>

Includes the given Resource by its TypeId in the save data.

pub fn exclude_component<T>(self) -> SaveWorld<F>
where T: Component,

Excludes the given Component from the save data.

pub fn exclude_component_by_id(self, type_id: TypeId) -> SaveWorld<F>

Excludes the given Component by its TypeId from the save data.

pub fn map_component<T>(self, m: impl MapComponent<T>) -> SaveWorld<F>
where T: Component,

Maps the given Component into another using a component mapper before saving.

Source

impl SaveWorld

pub fn default_into_file(path: impl Into<PathBuf>) -> SaveWorld

Creates a new SaveWorld event which saves default entities (with Save) into a file at the given path.

pub fn default_into_stream(stream: impl SaveStream) -> SaveWorld

Creates a new SaveWorld event which saves default entities (with Save) into a Write stream.

Source

impl SaveWorld<()>

pub fn all_into_file(path: impl Into<PathBuf>) -> SaveWorld<()>

Creates a new SaveWorld event which saves all entities into a file at the given path.

pub fn all_into_stream(stream: impl SaveStream) -> SaveWorld<()>

Creates a new SaveWorld event which saves all entities into a Write stream.