pub struct Merge<T>(pub T)
where
T: MergeComponent;Expand description
An EntityCommand which is used to add components.
Usage
It is impossible to have duplicate components on an Entity in Bevy.
However, in some cases, multiple instances of some components can be “merged” into one.
If a component implements MergeComponent, you can use this command to merge multiple instances
of the component into one.
use bevy::prelude::*;
use moonshine_util::prelude::*;
#[derive(Component, Default)]
struct N(usize);
impl MergeComponent for N {
fn merge(&mut self, other: Self) {
self.0 += other.0;
}
}
let mut world = World::new();
let entity = world.spawn_empty().id();
world.commands().entity(entity).queue(Merge(N(1)));
world.commands().entity(entity).queue(Merge(N(2)));
world.flush();
let &N(value) = world.get(entity).unwrap();
assert_eq!(value, 3);This command may also be used as a Component itself. This can be used in a Bundle or as a
requirement to merge components.
use bevy::prelude::*;
use moonshine_util::prelude::*;
#[derive(Component, Default)]
struct N(usize);
impl MergeComponent for N {
fn merge(&mut self, other: Self) {
self.0 += other.0;
}
}
let mut world = World::new();
let entity = world.spawn((N(1), Merge(N(2))));
let &N(value) = entity.get().unwrap();
assert_eq!(value, 3);Because Merge<T> is a component itself, it can be used as a component requirement.
However, because of the component uniqueness rule, multiple Merge<T> instances may not exist on the same entity.
To work around this, you can use MergeFrom and MergeWith.
Tuple Fields
0: TImplementations