pub struct Instance<T>(/* private fields */)
where
T: Kind;Expand description
Represents an Entity of Kind T.
Instance<Any> is functionally equivalent to an entity.
Usage
An Instance<T> can be used to access entities in a “kind-safe” manner to improve safety and readability.
This type is designed to behave exactly like an Entity.
This means you may use it as a Query parameter, pass it to Commands to access InstanceCommands<T>,
or store it as a type-safe reference to an Entity.
Note that an Instance<T> has 'static lifetime and does not contain any Component data.
It only contains type information.
Example
#[derive(Component)]
struct Apple;
#[derive(Component)]
struct Orange;
struct Fruit;
impl Kind for Fruit {
type Filter = Or<(With<Apple>, With<Orange>)>;
}
#[derive(Resource, Deref, DerefMut)]
struct FruitBasket(Vec<Instance<Fruit>>);
fn collect_fruits(mut basket: ResMut<FruitBasket>, fruits: Query<Instance<Fruit>>) {
for fruit in fruits.iter() {
println!("{fruit:?}");
basket.push(fruit);
}
}
Implementations
Sourceimpl<T> Instance<T>where
T: Kind,
impl<T> Instance<T>where
T: Kind,
Sourcepub const PLACEHOLDER: Instance<T>
pub const PLACEHOLDER: Instance<T>
Same as Entity::PLACEHOLDER, but for an Instance<T>.
Sourcepub unsafe fn from_entity_unchecked(entity: Entity) -> Instance<T>
pub unsafe fn from_entity_unchecked(entity: Entity) -> Instance<T>
Creates a new instance of kind T from some Entity.
Usage
This function is useful when you know an Entity is of a specific kind and you
need an Instance<T> with no way to validate it.
See Instance::from_entity for a safer alternative.
Safety
Assumes entity is a valid instance of kind T.
Example
#[derive(Component)]
struct Apple;
fn init_apple(entity: Entity, commands: &mut Commands) -> Instance<Apple> {
commands.entity(entity).insert(Apple);
// SAFE: `entity` will be a valid instance of `Apple`.
unsafe { Instance::from_entity_unchecked(entity) }
}Sourcepub fn cast_into<U>(self) -> Instance<U>
pub fn cast_into<U>(self) -> Instance<U>
Converts this instance into an instance of another kind Kind U.
Usage
A kind T is safety convertible to another kind U if T implements CastInto<U>.
Sourcepub fn cast_into_any(self) -> Instance<Any>
pub fn cast_into_any(self) -> Instance<Any>
Converts this instance into an instance of Kind Any.
Usage
Any Instance<T> can be safely cast into an Instance<Any> using this function.
Sourcepub unsafe fn cast_into_unchecked<U>(self) -> Instance<U>where
U: Kind,
pub unsafe fn cast_into_unchecked<U>(self) -> Instance<U>where
U: Kind,
Converts this instance into an instance of another kind Kind U without any validation.
Usage
This function is useful when you know an Instance<T> is convertible to a specific type and you
need an Instance<U> with no way to validate it.
Always prefer to explicitly declare safe casts with the CastInto trait and use Instance::cast_into.
Safety
Assumes this instance is also a valid Instance<U>.