pub struct SaveWorld<F = With<Save>>where
F: QueryFilter,{
pub entities: EntityFilter,
pub resources: SceneFilter,
pub components: SceneFilter,
pub mapper: SceneMapper,
pub output: SaveOutput,
/* private fields */
}Fields
entities: EntityFilterA filter for selecting which entities should be saved.
By default, all entities are selected.
resources: SceneFilterA filter for selecting which resources should be saved.
By default, no resources are selected. Most Bevy resources are not safely serializable.
components: SceneFilterA filter for selecting which components should be saved.
By default, all serializable components are selected.
mapper: SceneMapperA mapper for transforming components during the save process.
See MapComponent for more information.
output: SaveOutputOutput of the saved world.
Implementations
Sourceimpl<F> SaveWorld<F>where
F: QueryFilter,
impl<F> SaveWorld<F>where
F: QueryFilter,
Sourcepub fn new(output: SaveOutput) -> SaveWorld<F>
pub fn new(output: SaveOutput) -> SaveWorld<F>
Creates a new SaveWorld event with the given SaveOutput.
Sourcepub fn into_file(path: impl Into<PathBuf>) -> SaveWorld<F>
pub fn into_file(path: impl Into<PathBuf>) -> SaveWorld<F>
Creates a new SaveWorld event which saves entities matching the
given QueryFilter into a file at the given path.
Sourcepub fn into_stream(stream: impl SaveStream) -> SaveWorld<F>
pub fn into_stream(stream: impl SaveStream) -> SaveWorld<F>
Creates a new SaveWorld event which saves entities matching the
given QueryFilter into a Write stream.
Sourcepub fn include_resource<R>(self) -> SaveWorld<F>where
R: Resource,
pub fn include_resource<R>(self) -> SaveWorld<F>where
R: Resource,
Includes the given Resource in the save data.
Sourcepub fn include_resource_by_id(self, type_id: TypeId) -> SaveWorld<F>
pub fn include_resource_by_id(self, type_id: TypeId) -> SaveWorld<F>
Sourcepub fn exclude_component<T>(self) -> SaveWorld<F>where
T: Component,
pub fn exclude_component<T>(self) -> SaveWorld<F>where
T: Component,
Excludes the given Component from the save data.
Sourcepub fn exclude_component_by_id(self, type_id: TypeId) -> SaveWorld<F>
pub fn exclude_component_by_id(self, type_id: TypeId) -> SaveWorld<F>
Sourcepub fn map_component<T>(self, m: impl MapComponent<T>) -> SaveWorld<F>where
T: Component,
pub fn map_component<T>(self, m: impl MapComponent<T>) -> SaveWorld<F>where
T: Component,
Maps the given Component into another using a component mapper before saving.
Sourceimpl SaveWorld
impl SaveWorld
Sourcepub fn default_into_file(path: impl Into<PathBuf>) -> SaveWorld
pub fn default_into_file(path: impl Into<PathBuf>) -> SaveWorld
Sourcepub fn default_into_stream(stream: impl SaveStream) -> SaveWorld
pub fn default_into_stream(stream: impl SaveStream) -> SaveWorld