pub struct Expect<T>(/* private fields */);Expand description
A QueryData decorator which panics if its inner query does not match.
Usage
As a query parameter, this decorator is useful for preventing systems from silently skipping over entities which may erroneously not match the query.
Consider the following erroneous example:
use bevy::prelude::*;
#[derive(Component)]
struct A;
#[derive(Component)]
struct B;
// A and B are always expected to be inserted together:
#[derive(Bundle)]
struct AB {
a: A,
b: B,
}
fn bad_system(mut commands: Commands) {
commands.spawn(A); // Spawn A without B!
}
fn unsafe_system(q: Query<(&A, &B)>) {
for _ in q.iter() {
// An instance of `A` does exist.
// But because `A` does not exist *with* `B`, this system skips over it silently.
}
}This problem can be solved with Expect:
use moonshine_util::expect::Expect;
fn safe_system(q: Query<(&A, Expect<&B>)>) {
for _ in q.iter() {
// This system will panic if it finds an instance of `A` without `B`.
}
}Component Requirements
When used as a Component, this decorator will panic if the given component type T does
not exist on the entity. This is especially useful as a component requirement:
ⓘ
use moonshine_util::expect::Expect;
#[derive(Component)]
struct A;
#[derive(Component)]
#[require(Expect<A>)]
struct B;
fn unsafe_system(mut commands: Commands) {
commands.spawn(B); // Spawn B without A! This will panic!
}